searchData={"items":[{"type":"module","title":"ExZipProtect","doc":"Documentation for `ExZipProtect`.","ref":"ExZipProtect.html"},{"type":"function","title":"ExZipProtect.hello/0","doc":"Hello world.","ref":"ExZipProtect.html#hello/0"},{"type":"function","title":"Examples - ExZipProtect.hello/0","doc":"iex> ExZipProtect.hello()\n    :world","ref":"ExZipProtect.html#hello/0-examples"},{"type":"module","title":"ExZipProtect.Config","doc":"Provides convenient accessors for all `:ex_zip_protect` application\nconfiguration keys.\n\nThis module wraps calls to `Application.get_env/3` and exposes:\n\n  * `enabled?/0`      – whether the library is enabled (default: `true`)\n  * `rotation/0`      – rotation strategy (`:none`, `:round_robin`, etc.; default: `:none`)\n  * `levels/0`        – definitions of zip-bomb levels (default: `[]`)\n  * `bypass_header/0` – optional HTTP header to skip serving bombs (default: `nil`)\n\nAll values are fetched from the `:ex_zip_protect` OTP application environment.","ref":"ExZipProtect.Config.html"},{"type":"function","title":"ExZipProtect.Config.bypass_header/0","doc":"","ref":"ExZipProtect.Config.html#bypass_header/0"},{"type":"function","title":"ExZipProtect.Config.enabled?/0","doc":"","ref":"ExZipProtect.Config.html#enabled?/0"},{"type":"function","title":"ExZipProtect.Config.levels/0","doc":"","ref":"ExZipProtect.Config.html#levels/0"},{"type":"function","title":"ExZipProtect.Config.rotation/0","doc":"","ref":"ExZipProtect.Config.html#rotation/0"},{"type":"module","title":"ExZipProtect.Plug","doc":"Public entry point for serving pre‑built “zip bombs”.\n\n    alias ExZipProtect.Plug, as: Bomb\n    Bomb.send(conn, :medium)\n\n* **No‑op** if the library is disabled (`enabled?: false` in config).\n* **Bypass** if the request carries the user‑defined `bypass_header`.\n* Otherwise looks up the bomb spec for the given *level*, sets the\n  required response headers, streams the payload, and halts the\n  connection pipeline.","ref":"ExZipProtect.Plug.html"},{"type":"function","title":"ExZipProtect.Plug.send/3","doc":"Sends a bomb for `level` (`:low | :medium | :high | …`) and halts\nthe Plug pipeline. Optional `extra_headers` are merged into the\nresponse.","ref":"ExZipProtect.Plug.html#send/3"},{"type":"task","title":"mix ex_zip_protect.gen.config","doc":"Generates a starter configuration file for the `ex_zip_protect` library.\n\nThe `mix ex_zip_protect.gen.config` task will create\n`config/ex_zip_protect.exs` populated with sensible defaults\nfor:\n\n  * `enabled?`      – whether bombs are served (default: prod only)\n  * `rotation`      – bomb rotation strategy (`:none`, `:random`, `:round_robin`)\n  * `bypass_header` – optional header to skip serving bombs\n  * `levels`        – definitions of bomb levels and sources (file, S3, URL)","ref":"Mix.Tasks.ExZipProtect.Gen.Config.html"},{"type":"task","title":"Usage - mix ex_zip_protect.gen.config","doc":"mix ex_zip_protect.gen.config\n\nThis task will abort if `config/ex_zip_protect.exs` already exists.","ref":"Mix.Tasks.ExZipProtect.Gen.Config.html#module-usage"},{"type":"extras","title":"ExZipProtect","doc":"# ExZipProtect\n\n[![Module Version](https://img.shields.io/hexpm/v/ex_zip_protect.svg)](https://hex.pm/packages/ex_zip_protect)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ex_zip_protect/)\n[![Total Download](https://img.shields.io/hexpm/dt/ex_zip_protect.svg)](https://hex.pm/packages/ex_zip_protect)\n[![License](https://img.shields.io/hexpm/l/ex_zip_protect.svg)](https://hex.pm/packages/ex_zip_protect)\n[![Last Updated](https://img.shields.io/github/last-commit/houllette/ex_zip_protect.svg)](https://github.com/houllette/ex_zip_protect/commits/main)\n\nProtect your Phoenix/Plug applications from low‑effort scrapers, scanners, and spam bots by serving them **compressed \"zip bombs\"**—ultra‑small payloads that expand to hundreds of MB/GB and exhaust their memory.\n\nExZipProtect does **zero detection itself**; it simply makes it trivial for *you* to return a pre‑built bomb when your own heuristics say, “Nuke this request.”\n\n---","ref":"readme.html"},{"type":"extras","title":"✨ Features - ExZipProtect","doc":"| Feature                        | Details                                                                                                                                 |\n| ------------------------------ | --------------------------------------------------------------------------------------------------------------------------------------- |\n| **BYOB**                       | *Bring Your Own Bomb*—the library never ships with or generates payloads. You point to files you already built (gzip / zstd / brotli, etc.). |\n| **Multiple storage back‑ends** | `{:file, path}` · `{:s3, bucket: …, key: …}` · `{:url, \"https://…\"}`                                                                    |\n| **Rotation (opt‑in)**          | `:none` (default), `:random`, or `:round_robin` across multiple bombs per severity level.                                               |\n| **Staging safe‑guard**         | Entire library can be disabled with a single flag (default off in non‑`prod` envs).                                                     |\n| **Enable bypass header**       | Configure an optional HTTP header to serve as bypass to ExZipProtect (useful for security scanners).                                    |\n| **Telemetry audit event**      | Emits `[:ex_zip_protect, :bomb, :served]` so you can track activations.                                                                 |\n| **Mix generator**              | `mix ex_zip_protect.gen.config` scaffolds a ready‑to‑edit config file.                                                                  |\n\n---","ref":"readme.html#features"},{"type":"extras","title":"📦 Installation - ExZipProtect","doc":"Add to `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:ex_zip_protect, \"~> 0.1\"},\n\n    # OPTIONAL — required only if you use these source types:\n    {:ex_aws, \"~> 2.5\", optional: true}\n    {:ex_aws_s3, \"~> 2.5\", optional: true},   # for :s3 sources\n    {:finch,     \"~> 0.18\", optional: true}    # for :url streaming if not already in deps\n  ]\nend\n```\n\nRun `mix deps.get`.\n\n---","ref":"readme.html#installation"},{"type":"extras","title":"🔧 Quick start - ExZipProtect","doc":"```bash\n$ mix ex_zip_protect.gen.config   # creates config/ex_zip_protect.exs\n$ $EDITOR config/ex_zip_protect.exs   # edit paths / bucket names / rotation\n```\n\nThen in a controller or plug:\n\n```elixir\nalias ExZipProtect.Plug, as: Bomb\n\nplug :maybe_bomb\n\ndefp maybe_bomb(conn, _opts) do\n  case Detection.classify(conn) do\n    {:bomb, :low   } -> Bomb.send(conn, :low)\n    {:bomb, :medium} -> Bomb.send(conn, :medium)\n    {:bomb, :high  } -> Bomb.send(conn, :high)\n    _other           -> conn\n  end\nend\n```\n\nDone!  Your normal pipeline proceeds unless you explicitly call `Bomb.send/2`.\n\n---","ref":"readme.html#quick-start"},{"type":"extras","title":"⚙️ Configuration reference (config/*.exs) - ExZipProtect","doc":"```elixir\nimport Config\n\nconfig :ex_zip_protect,\n  enabled?: config_env() == :prod,   # disable library outside prod by default\n  rotation: :none,                  # :none | :random | :round_robin\n  levels: [\n    low:    [ %{source: {:file, \"/srv/bombs/low.gz\"},    encoding: :gzip} ],\n    medium: [ %{source: {:s3, bucket: \"bombs\", key: \"5mb.zst\"}, encoding: :zstd} ],\n    high:   [\n      %{source: {:url, \"https://cdn.example.com/10mb.br\"}, encoding: :br},\n      %{source: {:url, \"https://cdn2.example.com/20mb.br\"}, encoding: :br}\n    ]\n  ]\n```","ref":"readme.html#configuration-reference-config-exs"},{"type":"extras","title":"Keys - ExZipProtect","doc":"| Key               | Type         | Default | Notes                                                                                                             |\n| ----------------- | ------- | ------- | ----------------------------------------------------------------------------------------------------------------- |\n| `enabled?`        | bool    | `true`  | When `false`, `Bomb.send/2` is a no‑op.                                                                           |\n| `rotation`        | atom    | `:none` | Distribution strategy across a list of bombs for the same level.                                                  |\n| `levels`          | keyword | —       | Map severity `level => [bomb_spec, …]`.                                                                           |\n| `bypass_header`   | string  | nil     | If set, _any_ request containing that header bypasses bombs. Leave `nil` (or comment out) to disable the feature. |","ref":"readme.html#keys"},{"type":"extras","title":"Bomb spec - ExZipProtect","doc":"```elixir\n%{\n  source: {:file, \"/path\"} | {:s3, bucket: \"…\", key: \"…\", opts: [...] } | {:url, \"https://…\"},\n  encoding: :gzip | :zstd | :br | :deflate | atom(),\n  bytes: 1_000_000            # optional – sets Content‑Length without stat\n}\n```\n\n*If `:bytes` is absent*, ExZipProtect tries to derive size via `File.stat/2`, `HEAD` request, or S3 object metadata.\n\n---","ref":"readme.html#bomb-spec"},{"type":"extras","title":"💣 Bring Your Own Bomb (BYOB) - ExZipProtect","doc":"ExZipProtect **never** creates or bundles payloads. A few popular one‑liners:\n\n```bash\n# 1GB inflate → 1MB gzip\n$ dd if=/dev/zero bs=1G count=1 | gzip -c > 1mb-1gb.gz\n\n# 10GB inflate → 10MB zstd (fast)\n$ dd if=/dev/zero bs=1G count=10 | zstd -19 -o 10mb-10gb.zst\n\n# 50GB inflate → 10MB brotli (aggressive)\n$ dd if=/dev/zero bs=50G count=1 | brotli -q11 -o 10mb-50gb.br\n```\n\n> **Danger:** Decompressing these files locally may hang or crash your machine. Build them in a throwaway container or server.\n\nUpload the resulting file to your chosen storage, then reference it in `config`.\n\n---","ref":"readme.html#bring-your-own-bomb-byob"},{"type":"extras","title":"🚚 Where to host bombs? - ExZipProtect","doc":"| Source               | `source:` tuple                       | Pros                    | Cons                                   |\n| -------------------- | ------------------------------------- | ----------------------- | -------------------------------------- |\n| **Local file**       | `{:file, \"/srv/bombs/…\"}`             | Fast, no network        | Consumes disk on every app node        |\n| **S3 / GCS / MinIO** | `{:s3, bucket: \"…\", key: \"…\"}`        | Offloads storage; cheap | Requires `ex_aws_s3` dep & network I/O |\n| **HTTPS URL (CDN)**  | `{:url, \"https://cdn.example.com/…\"}` | Global edge caching     | Adds latency; ensure CORS/ACL OK       |\n\n---","ref":"readme.html#where-to-host-bombs"},{"type":"extras","title":"📈 Telemetry - ExZipProtect","doc":"`[:ex_zip_protect, :bomb, :served]`\n\n| Measurements                    | Metadata                   |\n| ------------------------------- | -------------------------- |\n| `:bytes` – size (or `:unknown`) | `:level`, `:ip`, `:source` |\n\nThe application supervisor attaches a default `Logger.warning/1` handler—you can detach it and forward to Honeycomb, Datadog, OpenTelemetry, etc.\n\n---","ref":"readme.html#telemetry"},{"type":"extras","title":"🛡️ Legal & ethical notes - ExZipProtect","doc":"* Serving bomb files is a form of denial‑of‑service **against the client**. Ensure this practice is allowed by your provider & jurisdiction.\n* Provide a bypass header (e.g. `X‑ZipBomb: false`) if you need certain security scanners to skip bombs.\n* Never serve bombs accidentally in dev/staging—leave `enabled?: config_env() == :prod`.\n\n---","ref":"readme.html#legal-ethical-notes"},{"type":"extras","title":"🛠️ Advanced topics - ExZipProtect","doc":"* **Streaming upgrades** — S3/URL senders are synchronous for now; PRs welcome for fully stream‑chunked variants.\n* **Custom rotation** — Implement the `ExZipProtect.Rotation` behaviour and set `rotation: MyModule`.\n\n---","ref":"readme.html#advanced-topics"},{"type":"extras","title":"🤝 Contributing - ExZipProtect","doc":"Issues and PRs are welcome!  Please run `mix test` and keep the `README.md` examples in sync.\n\n---","ref":"readme.html#contributing"},{"type":"extras","title":"📜 License - ExZipProtect","doc":"ExZipProtect is released under the MIT License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Added dynamic file sizing recognition of compressed file before serving","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"* Initial MVP","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.0"}}